@@ -40,9 +40,9 @@ class InitConfig(object):
     """
 
     def __init__(self):
-        self.version = '2.1.2'
+        self.version = '2.1.4'
         self.platform = sys.platform
-        self.system = platform.system()
+        self.system = platform.uname().version
         self.home_dir = os.path.expanduser('~')
         self.config_dir = os.path.join(self.home_dir,
                                        '.ssr-command-client')
